Learn R Programming

quanteda.tidy (version 0.4)

dplyr_pairs: Verbs that operate on pairs of data frames

Description

These functions combine a quanteda object with a data frame, adding new document variables based on matching values.

Value

A corpus with document variables from both x and y.

Arguments

x

a quanteda corpus object

y

a data frame to join with

...

additional arguments passed to methods

Details

left_join() adds columns from y to the corpus x, matching documents based on a key variable. All documents in x are kept. See dplyr::left_join() for more details.