These functions combine a quanteda object with a data frame, adding new document variables based on matching values.
A corpus with document variables from both x and y.
a quanteda corpus object
a data frame to join with
additional arguments passed to methods
left_join() adds columns from y to the corpus x, matching documents
based on a key variable. All documents in x are kept. See
dplyr::left_join() for more details.